@@ -1,27 +1,9 @@
-/***************************************************************************
+/*
     Smb4K's container class for information about a share.
-                             -------------------
-    begin                : Mo Jan 28 2008
-    copyright            : (C) 2008-2019 by Alexander Reinholdt
-    email                : alexander.reinholdt@kdemail.net
- ***************************************************************************/
 
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful, but   *
- *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
- *   General Public License for more details.                              *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc., 51 Franklin Street, Suite 500, Boston,*
- *   MA 02110-1335, USA                                                    *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2008-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef SMB4KSHARE_H
 #define SMB4KSHARE_H
@@ -30,11 +12,11 @@
 #include "smb4kbasicnetworkitem.h"
 
 // Qt includes
+#include <QHostAddress>
+#include <QScopedPointer>
 #include <QString>
 #include <QStringList>
 #include <QtGlobal>
-#include <QScopedPointer>
-#include <QHostAddress>
 
 // KDE includes
 #include <KCoreAddons/KUser>
@@ -45,42 +27,25 @@ class Smb4KSharePrivate;
 
 class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
 {
-  friend class Smb4KSharePrivate;
-  
-  public:
-    /**
-     * This constructor takes the host name @p hostName and the name of the
-     * shared resource @p shareName. All other information has to be set by the
-     * other functions this class provides.
-     *
-     * This constructor will also assemble the UNC from the provided arguments.
-     *
-     * @param hostName      The name of the host where the share is
-     *                      located.
-     *
-     * @param shareName     The name of the share.
-     */
-    Smb4KShare(const QString &hostName, const QString &shareName);
+    friend class Smb4KSharePrivate;
 
+public:
     /**
-     * This constructor takes the URL @p url as only argument. All other 
-     * information has to be set by the other functions this class provides.
+     * This constructor takes the URL @p url as argument.
      *
      * @param url           The URL
      */
     explicit Smb4KShare(const QUrl &url);
 
     /**
-     * This is the copy constructor. It takes another Smb4KShare item and copies all
-     * its values.
+     * This is the copy constructor.
      *
      * @param share         The Smb4KShare item that is to be copied
      */
     Smb4KShare(const Smb4KShare &share);
 
     /**
-     * The empty constructor. You need to set all information by the functions that
-     * are provided with this class.
+     * The empty constructor.
      */
     Smb4KShare();
 
@@ -116,26 +81,26 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @returns the host name
      */
     QString hostName() const;
-    
+
     /**
-     * In case of a 'homes' share, this function returns the URL of the user's 
+     * In case of a 'homes' share, this function returns the URL of the user's
      * home repository.
-     * 
+     *
      * If the share is not a 'homes' share or no user name for the homes share
      * has been defined, this function returns an empty string.
-     * 
+     *
      * @returns the user's home repository's URL.
      */
     QUrl homeUrl() const;
-    
+
     /**
      * Returns the display string. Prefer this over all other alternatives in your
      * GUI.
-     * 
+     *
      * @param showHomesShare  Show the name of the users home share instead of 'homes'
-     *                        in case this is a homes share. Setting this argument on a 
+     *                        in case this is a homes share. Setting this argument on a
      *                        non-homes share does nothing.
-     * 
+     *
      * @returns the display string.
      */
     QString displayString(bool showHomeShare = false) const;
@@ -154,10 +119,10 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @returns the workgroup name
      */
     QString workgroupName() const;
-    
+
     /**
      * Set the type of the share as reported by the server.
-     * 
+     *
      * @param type          The type of the string
      */
     void setShareType(Smb4KGlobal::ShareType type);
@@ -186,7 +151,7 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @param ip              The host's IP address
      */
     void setHostIpAddress(const QString &ip);
-    
+
     /**
      * Set the IP address of the host where the share is located. @p ip will only be accepted
      * if it is compatible with either IPv4 or IPv6.
@@ -203,10 +168,10 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @returns the IP address of the host or an empty string.
      */
     QString hostIpAddress() const;
-    
+
     /**
      * Returns TRUE if the host's IP address is set and FALSE otherwise.
-     * 
+     *
      * @returns TRUE if the host's IP address is set and FALSE otherwise.
      */
     bool hasHostIpAddress() const;
@@ -303,7 +268,7 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @returns the owner.
      */
     KUser user() const;
-    
+
     /**
      * Set the group that owns this share.
      * @param group            The owning GID
@@ -318,7 +283,7 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
     KUserGroup group() const;
 
     /**
-     * Sets the value of the total disk space that is available on the share. If 
+     * Sets the value of the total disk space that is available on the share. If
      * the disk usage could not be determined, @p size has to be set to 0.
      *
      * @param total           The total disk space that is available on the share
@@ -344,7 +309,7 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
     QString totalDiskSpaceString() const;
 
     /**
-     * Sets the value of the free disk space that is available on the share. If 
+     * Sets the value of the free disk space that is available on the share. If
      * the free disk space could not be determined, @p size has to be set to 0.
      *
      * @param free            The free disk space that is available on the share
@@ -358,7 +323,7 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @returns the free disk space or 0.
      */
     qulonglong freeDiskSpace() const;
-    
+
     /**
      * Returns the free disk space in a human readable form with value and unit
      * (e.g. 10 KiB, 25 MiB, etc.) even if the free disk space was not set or could
@@ -368,9 +333,9 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      * @returns the free disk space in a human readable form.
      */
     QString freeDiskSpaceString() const;
-    
+
     /**
-     * Sets the value of the disk space that is used on the share. If the used 
+     * Sets the value of the disk space that is used on the share. If the used
      * disk space could not be determined, @p size has to be set to 0.
      *
      * @param free            The free disk space that is available on the share
@@ -397,7 +362,7 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
 
     /**
      * Returns the disk usage in percent.
-     
+
      * @returns the disk usage in percent.
      */
     qreal diskUsage() const;
@@ -435,7 +400,7 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      *                        data should be copied.
      */
     void setMountData(Smb4KShare *share);
-    
+
     /**
      * This convenience function resets the mount related data.
      */
@@ -464,43 +429,33 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
     int port() const;
 
     /**
-     * Set the authentication information for the share. This function will add
-     * the authentication information to the URL of the share. Any previous
-     * user information including the login will be overwritten.
+     * Set the user name for the share.
      *
-     * @param authInfo    The authentication information
+     * @param name              The user name
      */
-    void setAuthInfo(Smb4KAuthInfo *authInfo);
-    
+    void setUserName(const QString &name);
+
     /**
-     * Set the login for the share. This function will add the login name
-     * to the URL of the share.
-     * 
-     * @param login       The login name
-     */
-    void setLogin(const QString &login);
-    
-    /**
-     * Returns the login.
+     * Returns the user name.
      *
-     * @returns the login.
+     * @returns the user name.
      */
-    QString login() const;
-    
+    QString userName() const;
+
     /**
      * Set the password used for authentication.
-     * 
+     *
      * @param passwd              The password
      */
     void setPassword(const QString &passwd);
-    
+
     /**
      * Returns the password.
-     * 
+     *
      * @returns the password.
      */
     QString password() const;
-    
+
     /**
      * Updates the share item if the workgroup name and the UNC of @p share and
      * of this item is equal. Otherwise it does nothing.
@@ -508,10 +463,10 @@ class Q_DECL_EXPORT Smb4KShare : public Smb4KBasicNetworkItem
      *                        this object
      */
     void update(Smb4KShare *share);
-    
-  private:
+
+private:
     const QScopedPointer<Smb4KSharePrivate> d;
-    
+
     /**
      * Set up the shares icon.
      */
